@@ -12,6 +12,8 @@
 #define FTP_EPSVALLOK         200
 #define FTP_STRUOK            200
 #define FTP_MODEOK            200
+#define FTP_PBSZOK            200
+#define FTP_PROTOK            200
 #define FTP_ALLOOK            202
 #define FTP_FEAT              211
 #define FTP_STATOK            211
@@ -29,6 +31,7 @@
 #define FTP_PASVOK            227
 #define FTP_EPSVOK            229
 #define FTP_LOGINOK           230
+#define FTP_AUTHOK            234
 #define FTP_CWDOK             250
 #define FTP_RMDIROK           250
 #define FTP_DELEOK            250
@@ -45,6 +48,7 @@
 #define FTP_TOO_MANY_USERS    421
 #define FTP_IP_LIMIT          421
 #define FTP_IP_DENY           421
+#define FTP_TLS_FAIL          421
 #define FTP_BADSENDCONN       425
 #define FTP_BADSENDNET        426
 #define FTP_BADSENDFILE       451
@@ -54,10 +58,17 @@
 #define FTP_COMMANDNOTIMPL    502
 #define FTP_NEEDUSER          503
 #define FTP_NEEDRNFR          503
+#define FTP_BADPBSZ           503
+#define FTP_BADPROT           503
 #define FTP_BADSTRU           504
 #define FTP_BADMODE           504
+#define FTP_BADAUTH           504
+#define FTP_NOSUCHPROT        504
+#define FTP_NEEDENCRYPT       521
 #define FTP_EPSVBAD           522
+#define FTP_DATATLSBAD        522
 #define FTP_LOGINERR          530
+#define FTP_NOHANDLEPROT      536
 #define FTP_FILEFAIL          550
 #define FTP_NOPERM            550
 #define FTP_UPLOADFAIL        553
