@@ -27,5 +27,19 @@ void vsf_ls_populate_dir_list(struct mystr_list* p_list,
                               const struct mystr* p_filter_str,
                               int is_verbose);
 
+/* vsf_filename_passes_filter()
+ * PURPOSE
+ * Determine whether the given filename is matched by the given filter string.
+ * The format of the filter string is a small subset of a regular expression.
+ * Currently, just * and ? are supported.
+ * PARAMETERS
+ * p_filename_str  - the filename to match
+ * p_filter_str    - the filter to match against
+ * RETURNS
+ * Returns 1 if there is a match, 0 otherwise.
+ */
+int vsf_filename_passes_filter(const struct mystr* p_filename_str,
+                               const struct mystr* p_filter_str);
+
 #endif /* VSF_LS_H */
 
