@@ -1,6 +1,6 @@
 /*
  * Part of Very Secure FTPd
- * Licence: GPL
+ * Licence: GPL v2
  * Author: Chris Evans
  * postprivparent.c
  *
@@ -44,7 +44,7 @@ process_post_login_req(struct vsf_session* p_sess)
   char cmd;
   vsf_sysutil_unblock_sig(kVSFSysUtilSigCHLD);
   /* Blocks */
-  cmd = priv_sock_get_cmd(p_sess);
+  cmd = priv_sock_get_cmd(p_sess->parent_fd);
   vsf_sysutil_block_sig(kVSFSysUtilSigCHLD);
   if (tunable_chown_uploads && cmd == PRIV_SOCK_CHOWN)
   {
@@ -106,18 +106,18 @@ minimize_privilege(struct vsf_session* p_sess)
 static void
 cmd_process_chown(struct vsf_session* p_sess)
 {
-  int the_fd = priv_sock_parent_recv_fd(p_sess);
+  int the_fd = priv_sock_recv_fd(p_sess->parent_fd);
   vsf_privop_do_file_chown(p_sess, the_fd);
   vsf_sysutil_close(the_fd);
-  priv_sock_send_result(p_sess, PRIV_SOCK_RESULT_OK);
+  priv_sock_send_result(p_sess->parent_fd, PRIV_SOCK_RESULT_OK);
 }
 
 static void
 cmd_process_get_data_sock(struct vsf_session* p_sess)
 {
   int sock_fd = vsf_privop_get_ftp_port_sock(p_sess);
-  priv_sock_send_result(p_sess, PRIV_SOCK_RESULT_OK);
-  priv_sock_parent_send_fd(p_sess, sock_fd);
+  priv_sock_send_result(p_sess->parent_fd, PRIV_SOCK_RESULT_OK);
+  priv_sock_send_fd(p_sess->parent_fd, sock_fd);
   vsf_sysutil_close(sock_fd);
 }
 
